@@ -9,8 +9,8 @@
 #
 package Test::Moose::More;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-# git description: 0.039-12-gf95fd48
-$Test::Moose::More::VERSION = '0.040'; # TRIAL
+# git description: 0.040-16-gb23f2af
+$Test::Moose::More::VERSION = '0.041'; # TRIAL
 
 # ABSTRACT: More tools for testing Moose packages
 
@@ -48,8 +48,13 @@ use Sub::Exporter::Progressive -setup => {
         is_class
         is_not_anon
         is_role
+
+        does_metaroles_ok
     } ],
-    groups  => { default => [ ':all' ] },
+    groups => {
+        default  => [ ':all' ],
+        validate => [ map { "validate_$_" } qw{ attribute class role thing } ],
+    },
 };
 
 use Test::Builder;
@@ -61,6 +66,8 @@ use Moose::Util 'resolve_metatrait_alias', 'does_role', 'find_meta';
 use Moose::Util::TypeConstraints;
 use Data::OptList;
 
+use Test::Moose::More::Utils;
+
 # debugging...
 #use Smart::Comments;
 
@@ -286,8 +293,6 @@ sub is_not_anon_ok ($) {
 }
 
 
-sub known_sugar () { qw{ has around augment inner before after blessed confess } }
-
 sub check_sugar_removed_ok ($) {
     my $t = shift @_;
 
@@ -308,6 +313,25 @@ sub check_sugar_ok ($) {
 }
 
 
+sub does_metaroles_ok($$) {
+    my ($thing, $metaroles) = @_;
+
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+
+    my $meta = find_meta($thing);
+    my $name = _thing_name($thing, $meta);
+
+    for my $mop (sort keys %$metaroles) {
+
+        my $mop_metaclass = get_mop_metaclass_for $mop => $meta;
+
+        local $THING_NAME = "${name}'s $mop metaclass $mop_metaclass";
+        does_ok $mop_metaclass => $metaroles->{$mop};
+    }
+
+    return;
+}
+
 
 sub validate_thing ($@) { _validate_subtest_wrapper(\&_validate_thing_guts, @_) }
 sub validate_class ($@) { _validate_subtest_wrapper(\&_validate_class_guts, @_) }
@@ -438,6 +462,7 @@ sub _validate_role_guts {
     $args{does} = [ $role, @{ $args{does} || [] } ];
 
     # aaaand a subtest wrapper to make it easier to read...
+    local $THING_NAME = _thing_name($role) . q{'s composed class};
     return validate_class $anon->name => (
         -subtest => 'role composed into ' . $anon->name,
         %args,
@@ -620,7 +645,7 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Chris Weyl Chad Etheridge Granum Karen subtest
+=for :stopwords Chris Weyl Chad Etheridge Granum Karen subtest MOPs
 
 =for :stopwords Wishlist flattr flattr'ed gittip gittip'ed
 
@@ -630,7 +655,7 @@ Test::Moose::More - More tools for testing Moose packages
 
 =head1 VERSION
 
-This document describes version 0.040 of Test::Moose::More - released November 10, 2016 as part of Test-Moose-More.
+This document describes version 0.041 of Test::Moose::More - released November 12, 2016 as part of Test-Moose-More.
 
 =head1 SYNOPSIS
 
@@ -648,11 +673,23 @@ This package contains a number of additional tests that can be employed
 against Moose classes/roles.  It is intended to replace L<Test::Moose> in your
 tests, and re-exports any tests that it has and we do not, yet.
 
-=head1 FUNCTIONS
+=head2 Export Groups
 
-=head2 known_sugar
+By default, this package exports all test functions.  You can be more
+selective, however, and there are a number of export groups (aside from the
+default ':all') to help you achieve those dreams!
 
-Returns a list of all the known standard Moose sugar (has, extends, etc).
+=over 4
+
+=item :all
+
+All exportable functions.
+
+=item :validate
+
+L</validate_attribute>, L</validate_class>, L</validate_role>, L</validate_thing>
+
+=back
 
 =head1 TEST FUNCTIONS
 
@@ -741,6 +778,70 @@ given package.
 
 Checks and makes sure a class/etc can still do all the standard Moose sugar.
 
+=head2 does_metaroles_ok $thing => { $mop => [ @traits ], ... };
+
+Validate the metaclasses associated with a class/role metaclass.
+
+e.g., if I wanted to validate that the attribute trait for
+L<MooseX::AttributeShortcuts> is actually applied, I could do this:
+
+    { package TestClass; use Moose; use MooseX::AttributeShortcuts; }
+    use Test::Moose::More;
+    use Test::More;
+
+    does_metaroles_ok TestClass => {
+       attribute => ['MooseX::AttributeShortcuts::Trait::Attribute'],
+    };
+    done_testing;
+
+This function will accept either class or role metaclasses for $thing.
+
+The MOPs available for classes (L<Moose::Meta::Class>) are:
+
+=over 4
+
+=item class
+
+=item attribute
+
+=item method
+
+=item wrapped_method
+
+=item instance
+
+=item constructor
+
+=item destructor
+
+=back
+
+The MOPs available for roles (L<Moose::Meta::Role>) are:
+
+=over 4
+
+=item role
+
+=item attribute
+
+=item method
+
+=item required_method
+
+=item wrapped_method
+
+=item conflicting_method
+
+=item application_to_class
+
+=item application_to_role
+
+=item application_to_instance
+
+=item applied_attribute
+
+=back
+
 =head2 validate_thing
 
 Runs a bunch of tests against the given C<$thing>, as defined:
@@ -862,14 +963,14 @@ e.g.:
     ok 5 - TestRole does not do TestRole::Two
     ok 6 - TestRole has method method1
     ok 7 - TestRole has an attribute named bar
-        # Subtest: role composed into Moose::Meta::Class::__ANON__::SERIAL::1
-        ok 1 - Moose::Meta::Class::__ANON__::SERIAL::1 has a metaclass
-        ok 2 - Moose::Meta::Class::__ANON__::SERIAL::1 is a Moose class
-        ok 3 - Moose::Meta::Class::__ANON__::SERIAL::1 does TestRole
-        ok 4 - Moose::Meta::Class::__ANON__::SERIAL::1 does not do TestRole::Two
-        ok 5 - Moose::Meta::Class::__ANON__::SERIAL::1 has method method1
-        ok 6 - Moose::Meta::Class::__ANON__::SERIAL::1 has method blargh
-        ok 7 - Moose::Meta::Class::__ANON__::SERIAL::1 has an attribute named bar
+    # Subtest: role composed into Moose::Meta::Class::__ANON__::SERIAL::1
+        ok 1 - TestRole's composed class has a metaclass
+        ok 2 - TestRole's composed class is a Moose class
+        ok 3 - TestRole's composed class does TestRole
+        ok 4 - TestRole's composed class does not do TestRole::Two
+        ok 5 - TestRole's composed class has method method1
+        ok 6 - TestRole's composed class has method blargh
+        ok 7 - TestRole's composed class has an attribute named bar
         1..7
     ok 8 - role composed into Moose::Meta::Class::__ANON__::SERIAL::1
     1..8
